@@ -3,7 +3,7 @@
   SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
-  SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2022 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
@@ -15,6 +15,7 @@
 
 #include <cmath>
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/Item>
 
 #include <KCalendarCore/Visitor>
@@ -37,9 +38,7 @@ CalPrintIncidence::CalPrintIncidence()
 {
 }
 
-CalPrintIncidence::~CalPrintIncidence()
-{
-}
+CalPrintIncidence::~CalPrintIncidence() = default;
 
 QWidget *CalPrintIncidence::createConfigWidget(QWidget *w)
 {
@@ -103,9 +102,7 @@ void CalPrintIncidence::doSaveConfig()
 class TimePrintStringsVisitor : public KCalendarCore::Visitor
 {
 public:
-    TimePrintStringsVisitor()
-    {
-    }
+    TimePrintStringsVisitor() = default;
 
     bool act(KCalendarCore::IncidenceBase::Ptr incidence)
     {
@@ -468,7 +465,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
                 QString datesString;
                 int count = 0;
                 for (const Akonadi::Item &item : std::as_const(relations)) {
-                    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(item);
+                    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(item);
                     ++count;
                     if (!todo) { // defensive, skip any zero pointers
                         continue;
@@ -643,9 +640,7 @@ CalPrintTimetable::CalPrintTimetable()
 {
 }
 
-CalPrintTimetable::~CalPrintTimetable()
-{
-}
+CalPrintTimetable::~CalPrintTimetable() = default;
 
 void CalPrintTimetable::doLoadConfig()
 {
@@ -692,11 +687,7 @@ static QString cleanString(const QString &instr)
     return ret.replace(QLatin1Char('\n'), QLatin1Char(' '));
 }
 
-void CalPrintTimetable::drawAllDayBox(QPainter &p,
-                                      const KCalendarCore::Event::List &eventList,
-                                      QDate qd,
-                                      QRect box,
-                                      const QList<QDate> &workDays)
+void CalPrintTimetable::drawAllDayBox(QPainter &p, const KCalendarCore::Event::List &eventList, QDate qd, QRect box, const QList<QDate> &workDays)
 {
     int lineSpacing = p.fontMetrics().lineSpacing();
 
@@ -711,9 +702,7 @@ void CalPrintTimetable::drawAllDayBox(QPainter &p,
     eventBox.setBottom(eventBox.top() + lineSpacing);
 
     for (const KCalendarCore::Event::Ptr &currEvent : std::as_const(eventList)) {
-        if (!currEvent
-            || !currEvent->allDay()
-            || (mExcludeConfidential && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+        if (!currEvent || !currEvent->allDay() || (mExcludeConfidential && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
             || (mExcludePrivate && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
             continue;
         }
@@ -724,7 +713,7 @@ void CalPrintTimetable::drawAllDayBox(QPainter &p,
             str = i18nc("summary, location", "%1, %2", cleanString(currEvent->summary()), cleanString(currEvent->location()));
         }
         if (mIncludeCategories && !currEvent->categoriesStr().isEmpty()) {
-                str = i18nc("summary, categories", "%1, %2", str, currEvent->categoriesStr());
+            str = i18nc("summary, categories", "%1, %2", str, currEvent->categoriesStr());
         }
         printEventString(p, eventBox, str);
         eventBox.setTop(eventBox.bottom());
@@ -732,10 +721,7 @@ void CalPrintTimetable::drawAllDayBox(QPainter &p,
     }
 }
 
-void CalPrintTimetable::drawTimeTable(QPainter &p,
-                                       QDate fromDate,
-                                       QDate toDate,
-                                       QRect box)
+void CalPrintTimetable::drawTimeTable(QPainter &p, QDate fromDate, QDate toDate, QRect box)
 {
     QTime myFromTime = mStartTime;
     QTime myToTime = mEndTime;
@@ -747,8 +733,7 @@ void CalPrintTimetable::drawTimeTable(QPainter &p,
         int allDayEvents = holiday(curDate).isEmpty() ? 0 : 1;
         for (const KCalendarCore::Event::Ptr &event : std::as_const(eventList)) {
             Q_ASSERT(event);
-            if (!event
-                || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+            if (!event || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
                 || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
                 continue;
             }
@@ -784,18 +769,18 @@ void CalPrintTimetable::drawTimeTable(QPainter &p,
     int alldayHeight = 0;
     if (maxAllDayEvents > 0) {
         // Draw the side bar for all-day events.
-        const auto alldayLabel =  i18nc("label for timetable all-day boxes", "All day");
+        const auto alldayLabel = i18nc("label for timetable all-day boxes", "All day");
         const QFont oldFont(p.font());
         p.setFont(QFont(QStringLiteral("sans-serif"), 9, QFont::Normal));
-        const auto labelHeight = p.fontMetrics().horizontalAdvance(alldayLabel) + 2*padding();
-        alldayHeight = std::max(maxAllDayEvents*lineSpacing + 2*padding(), labelHeight);
+        const auto labelHeight = p.fontMetrics().horizontalAdvance(alldayLabel) + 2 * padding();
+        alldayHeight = std::max(maxAllDayEvents * lineSpacing + 2 * padding(), labelHeight);
         drawVerticalBox(p,
                         BOX_BORDER_WIDTH,
                         QRect(0, tlTop, TIMELINE_WIDTH, alldayHeight),
                         alldayLabel,
                         Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap);
         p.setFont(oldFont);
-        tlTop += alldayHeight +padding();
+        tlTop += alldayHeight + padding();
     }
 
     QRect tlBox(box);
@@ -825,17 +810,7 @@ void CalPrintTimetable::drawTimeTable(QPainter &p,
         QRect dayBox(allDayBox);
         dayBox.setTop(tlTop);
         dayBox.setBottom(box.bottom());
-        drawAgendaDayBox(p,
-                         eventList,
-                         curDate,
-                         false,
-                         myFromTime,
-                         myToTime,
-                         dayBox,
-                         mIncludeDescription,
-                         mIncludeCategories,
-                         mExcludeTime,
-                         workDays);
+        drawAgendaDayBox(p, eventList, curDate, false, myFromTime, myToTime, dayBox, mIncludeDescription, mIncludeCategories, mExcludeTime, workDays);
 
         ++i;
         curDate = curDate.addDays(1);
@@ -851,9 +826,7 @@ CalPrintDay::CalPrintDay()
 {
 }
 
-CalPrintDay::~CalPrintDay()
-{
-}
+CalPrintDay::~CalPrintDay() = default;
 
 QWidget *CalPrintDay::createConfigWidget(QWidget *w)
 {
@@ -975,17 +948,7 @@ void CalPrintDay::drawDays(QPainter &p, QRect box)
         const int hpos = i / vcells;
         const int vpos = i % vcells;
         const QRect dayBox(box.left() + cellWidth * hpos, box.top() + cellHeight * vpos, cellWidth, cellHeight);
-        drawDayBox(p,
-                   weekDate,
-                   mStartTime,
-                   mEndTime,
-                   dayBox,
-                   true,
-                   true,
-                   true,
-                   mSingleLineLimit,
-                   mIncludeDescription,
-                   mIncludeCategories);
+        drawDayBox(p, weekDate, mStartTime, mEndTime, dayBox, true, true, true, mSingleLineLimit, mIncludeDescription, mIncludeCategories);
     } // for i through all selected days
 }
 
@@ -1011,7 +974,7 @@ void CalPrintDay::print(QPainter &p, int width, int height)
         if (mFromDate == mToDate) {
             title = line1;
         } else {
-            title =  i18nc("date from-to", "%1\u2013%2", line1, line2);
+            title = i18nc("date from-to", "%1\u2013%2", line1, line2);
         }
         drawHeader(p, title, mFromDate, QDate(), headerBox);
         if (mDayPrintType == Filofax) {
@@ -1061,9 +1024,7 @@ CalPrintWeek::CalPrintWeek()
 {
 }
 
-CalPrintWeek::~CalPrintWeek()
-{
-}
+CalPrintWeek::~CalPrintWeek() = default;
 
 QWidget *CalPrintWeek::createConfigWidget(QWidget *w)
 {
@@ -1174,9 +1135,7 @@ void CalPrintWeek::setDateRange(const QDate &from, const QDate &to)
     }
 }
 
-void CalPrintWeek::drawWeek(QPainter &p,
-                                  QDate qd,
-                                  QRect box)
+void CalPrintWeek::drawWeek(QPainter &p, QDate qd, QRect box)
 {
     QDate weekDate = qd;
     const bool portrait = (box.height() > box.width());
@@ -1203,17 +1162,7 @@ void CalPrintWeek::drawWeek(QPainter &p,
                      box.top() + cellHeight * vpos + ((i == 6) ? (cellHeight / 2) : 0),
                      cellWidth,
                      (i < 5) ? (cellHeight) : (cellHeight / 2));
-        drawDayBox(p,
-                   weekDate,
-                   mStartTime,
-                   mEndTime,
-                   dayBox,
-                   true,
-                   true,
-                   true,
-                   mSingleLineLimit,
-                   mIncludeDescription,
-                   mIncludeCategories);
+        drawDayBox(p, weekDate, mStartTime, mEndTime, dayBox, true, true, true, mSingleLineLimit, mIncludeDescription, mIncludeCategories);
     } // for i through all weekdays
 }
 
@@ -1248,7 +1197,7 @@ void CalPrintWeek::print(QPainter &p, int width, int height)
         do {
             line1 = local.toString(curWeek.addDays(-6), QLocale::ShortFormat);
             line2 = local.toString(curWeek, QLocale::ShortFormat);
-            title =  i18nc("date from-to", "%1\u2013%2", line1, line2);
+            title = i18nc("date from-to", "%1\u2013%2", line1, line2);
             drawHeader(p, title, curWeek.addDays(-6), QDate(), headerBox);
 
             drawWeek(p, curWeek, weekBox);
@@ -1333,9 +1282,7 @@ CalPrintMonth::CalPrintMonth()
 {
 }
 
-CalPrintMonth::~CalPrintMonth()
-{
-}
+CalPrintMonth::~CalPrintMonth() = default;
 
 QWidget *CalPrintMonth::createConfigWidget(QWidget *w)
 {
@@ -1424,13 +1371,13 @@ void CalPrintMonth::setDateRange(const QDate &from, const QDate &to)
     CalPrintPluginBase::setDateRange(from, to);
     auto cfg = dynamic_cast<CalPrintMonthConfig *>((QWidget *)mConfigWidget);
     if (cfg) {
+        const QLocale locale;
         cfg->mFromMonth->clear();
-        for (int i = 0; i < 12; ++i) {
-            cfg->mFromMonth->addItem(QLocale().monthName(i + 1, QLocale::LongFormat));
-        }
         cfg->mToMonth->clear();
-        for (int i = 0; i < 12; ++i) {
-            cfg->mToMonth->addItem(QLocale().monthName(i + 1, QLocale::LongFormat));
+        for (int i = 1; i < 13; ++i) {
+            const auto monthName = locale.standaloneMonthName(i, QLocale::LongFormat);
+            cfg->mFromMonth->addItem(monthName);
+            cfg->mToMonth->addItem(monthName);
         }
         cfg->mFromMonth->setCurrentIndex(from.month() - 1);
         cfg->mFromYear->setValue(to.year());
@@ -1458,7 +1405,8 @@ void CalPrintMonth::print(QPainter &p, int width, int height)
     monthBox.setTop(headerBox.bottom() + padding());
 
     do {
-        QString title(i18nc("monthname year", "%1 %2", QLocale::system().monthName(curMonth.month()), QString::number(curMonth.year())));
+        QString title(
+            i18nc("monthname year", "%1 %2", QLocale::system().standaloneMonthName(curMonth.month(), QLocale::LongFormat), QString::number(curMonth.year())));
         QDate tmp(fromMonth);
         int weekdayCol = weekdayColumn(tmp.dayOfWeek());
         tmp = tmp.addDays(-weekdayCol);
@@ -1498,9 +1446,7 @@ CalPrintTodos::CalPrintTodos()
     mTodoSortDirection = TodoDirectionUnset;
 }
 
-CalPrintTodos::~CalPrintTodos()
-{
-}
+CalPrintTodos::~CalPrintTodos() = default;
 
 QWidget *CalPrintTodos::createConfigWidget(QWidget *w)
 {
@@ -1571,7 +1517,7 @@ void CalPrintTodos::setSettingsWidget()
 
         if (mTodoSortField != TodoFieldUnset) {
             // do not insert if already done so.
-            cfg->mSortField->addItem(i18nc("@option sort by title", "Title"));
+            cfg->mSortField->addItem(i18nc("@option sort by summary", "Summary"));
             cfg->mSortField->addItem(i18nc("@option sort by start date/time", "Start Date"));
             cfg->mSortField->addItem(i18nc("@option sort by due date/time", "Due Date"));
             cfg->mSortField->addItem(i18nc("@option sort by priority", "Priority"));
@@ -1664,7 +1610,7 @@ void CalPrintTodos::print(QPainter &p, int width, int height)
         p.drawText(pospriority, mCurrentLinePos - 2, outStr);
     }
 
-    int posSoFar = width;  // Position of leftmost optional header.
+    int posSoFar = width; // Position of leftmost optional header.
 
     int posdue = -1;
     if (mIncludeDueDate) {
