@@ -13,6 +13,7 @@
 #include "utils.h"
 
 #include <Akonadi/Item>
+#include <Akonadi/TagCache>
 
 #include "calendarsupport_debug.h"
 #include <KConfig>
@@ -73,22 +74,22 @@ public:
     {
     }
 
-    KCalendarCore::Event::Ptr event() const
+    Q_REQUIRED_RESULT KCalendarCore::Event::Ptr event() const
     {
         return mEvent;
     }
 
-    QString label() const override
+    Q_REQUIRED_RESULT QString label() const override
     {
         return mEvent->summary();
     }
 
-    QDateTime start() const
+    Q_REQUIRED_RESULT QDateTime start() const
     {
         return mStart;
     }
 
-    QDateTime end() const
+    Q_REQUIRED_RESULT QDateTime end() const
     {
         return mEnd;
     }
@@ -122,9 +123,7 @@ CalPrintPluginBase::CalPrintPluginBase()
 {
 }
 
-CalPrintPluginBase::~CalPrintPluginBase()
-{
-}
+CalPrintPluginBase::~CalPrintPluginBase() = default;
 
 QWidget *CalPrintPluginBase::createConfigWidget(QWidget *w)
 {
@@ -269,18 +268,13 @@ void CalPrintPluginBase::setColorsByIncidenceCategory(QPainter &p, const KCalend
 
 QColor CalPrintPluginBase::categoryColor(const QStringList &categories) const
 {
-    if (categories.isEmpty()) {
-        return KCalPrefs::instance()->unsetCategoryColor();
-    }
     // FIXME: Correctly treat events with multiple categories
-    const QString cat = categories.at(0);
     QColor bgColor;
-    if (cat.isEmpty()) {
-        bgColor = KCalPrefs::instance()->unsetCategoryColor();
-    } else {
-        bgColor = KCalPrefs::instance()->categoryColor(cat);
+    if (!categories.isEmpty()) {
+        bgColor = Akonadi::TagCache::instance()->tagColor(categories.at(0));
     }
-    return bgColor;
+
+    return bgColor.isValid() ? bgColor : KCalPrefs::instance()->unsetCategoryColor();
 }
 
 QColor CalPrintPluginBase::categoryBgColor(const KCalendarCore::Incidence::Ptr &incidence) const
@@ -294,7 +288,7 @@ QColor CalPrintPluginBase::categoryBgColor(const KCalendarCore::Incidence::Ptr &
         }
         return backColor;
     } else {
-        return QColor();
+        return {};
     }
 }
 
@@ -308,7 +302,7 @@ KCalendarCore::Event::Ptr CalPrintPluginBase::holidayEvent(QDate date) const
 {
     QString hstring(holidayString(date));
     if (hstring.isEmpty()) {
-        return KCalendarCore::Event::Ptr();
+        return {};
     }
 
     KCalendarCore::Event::Ptr holiday(new KCalendarCore::Event);
@@ -585,7 +579,7 @@ int CalPrintPluginBase::drawHeader(QPainter &p, const QString &title, QDate mont
 
     drawShadedBox(p, BOX_BORDER_WIDTH, backColor, box);
 
-    const auto oldPen {p.pen()};
+    const auto oldPen{p.pen()};
     p.setPen(getTextColor(backColor));
 
     // prev month left, current month centered, next month right
@@ -638,10 +632,12 @@ void CalPrintPluginBase::drawSmallMonth(QPainter &p, QDate qd, QRect box)
     newFont.setPixelSize(cellHeight);
     p.setFont(newFont);
 
+    const QLocale locale;
+
     // draw the title
     QRect titleBox(box);
     titleBox.setHeight(p.fontMetrics().height());
-    p.drawText(titleBox, Qt::AlignTop | Qt::AlignHCenter, QLocale::system().monthName(month));
+    p.drawText(titleBox, Qt::AlignTop | Qt::AlignHCenter, locale.standaloneMonthName(month));
 
     // draw days of week
     QRect wdayBox(box);
@@ -649,10 +645,10 @@ void CalPrintPluginBase::drawSmallMonth(QPainter &p, QDate qd, QRect box)
     wdayBox.setHeight(int(2 * cellHeight) - int(cellHeight));
 
     for (int col = 0; col < 7; ++col) {
-        QString tmpStr = QLocale::system().dayName(monthDate2.dayOfWeek())[0].toUpper();
+        const auto dayLetter = locale.standaloneDayName(monthDate2.dayOfWeek(), QLocale::ShortFormat)[0].toUpper();
         wdayBox.setLeft(int(box.left() + col * cellWidth));
         wdayBox.setRight(int(box.left() + (col + 1) * cellWidth));
-        p.drawText(wdayBox, Qt::AlignCenter, tmpStr);
+        p.drawText(wdayBox, Qt::AlignCenter, dayLetter);
         monthDate2 = monthDate2.addDays(1);
     }
 
@@ -801,8 +797,7 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
         // Adapt start/end times to include complete events
         for (const KCalendarCore::Event::Ptr &event : std::as_const(events)) {
             Q_ASSERT(event);
-            if (!event
-                || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+            if (!event || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
                 || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
                 continue;
             }
@@ -858,8 +853,7 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
     QList<CellItem *> cells;
 
     for (const KCalendarCore::Event::Ptr &event : std::as_const(events)) {
-        if (!event
-            || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+        if (!event || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
             || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
             continue;
         }
@@ -938,7 +932,7 @@ void CalPrintPluginBase::drawAgendaItem(PrintCellItem *item,
             }
         }
         if (includeCategories && !event->categoriesStr().isEmpty()) {
-                str = i18nc("summary, categories", "%1, %2", str, event->categoriesStr());
+            str = i18nc("summary, categories", "%1, %2", str, event->categoriesStr());
         }
         if (includeDescription && !event->description().isEmpty()) {
             str += QLatin1Char('\n');
@@ -1162,7 +1156,7 @@ void CalPrintPluginBase::drawIncidence(QPainter &p,
     QFontMetrics fm = p.fontMetrics();
     const int borderWidth = p.pen().width() + 1;
 
-    QString firstLine {time};
+    QString firstLine{time};
     if (!firstLine.isEmpty()) {
         firstLine += QStringLiteral(" ");
     }
@@ -1261,19 +1255,14 @@ public:
     KCalendarCore::Event::Ptr event;
 };
 
-void CalPrintPluginBase::drawMonth(QPainter &p,
-                                   QDate dt,
-                                   QRect box,
-                                   int maxdays,
-                                   int subDailyFlags,
-                                   int holidaysFlags)
+void CalPrintPluginBase::drawMonth(QPainter &p, QDate dt, QRect box, int maxdays, int subDailyFlags, int holidaysFlags)
 {
     p.save();
     QRect subheaderBox(box);
     subheaderBox.setHeight(subHeaderHeight());
     QRect borderBox(box);
     borderBox.setTop(subheaderBox.bottom() + 1);
-    drawSubHeaderBox(p, QLocale::system().monthName(dt.month()), subheaderBox);
+    drawSubHeaderBox(p, QLocale().standaloneMonthName(dt.month()), subheaderBox);
     // correct for half the border width
     int correction = (BOX_BORDER_WIDTH /*-1*/) / 2;
     QRect daysBox(borderBox);
@@ -1356,8 +1345,7 @@ void CalPrintPluginBase::drawMonth(QPainter &p,
     QVector<MonthEventStruct> monthentries;
 
     for (const KCalendarCore::Event::Ptr &e : std::as_const(events)) {
-        if (!e
-            || (mExcludeConfidential && e->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+        if (!e || (mExcludeConfidential && e->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
             || (mExcludePrivate && e->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
             continue;
         }
@@ -1531,17 +1519,7 @@ void CalPrintPluginBase::drawMonthTable(QPainter &p,
                 darkbg = true;
             }
             QRect dayBox(coledges[col], rowedges[row], coledges[col + 1] - coledges[col], rowedges[row + 1] - rowedges[row]);
-            drawDayBox(p,
-                       monthDate,
-                       fromTime,
-                       toTime,
-                       dayBox,
-                       false,
-                       recurDaily,
-                       recurWeekly,
-                       singleLineLimit,
-                       includeDescription,
-                       includeCategories);
+            drawDayBox(p, monthDate, fromTime, toTime, dayBox, false, recurDaily, recurWeekly, singleLineLimit, includeDescription, includeCategories);
             if (darkbg) {
                 p.setBackground(back);
                 darkbg = false;
@@ -1683,7 +1661,7 @@ void CalPrintPluginBase::drawTodo(int &count,
         p.drawLine(center, bottom, center, to);
     }
 
-    int posSoFar = width;  // Position of leftmost optional field.
+    int posSoFar = width; // Position of leftmost optional field.
 
     // due date
     if (posDueDt >= 0 && todo->hasDueDate()) {
@@ -1723,7 +1701,7 @@ void CalPrintPluginBase::drawTodo(int &count,
     }
 
     // categories
-    QRect categoriesRect {0, 0, 0, 0};
+    QRect categoriesRect{0, 0, 0, 0};
     if (posCategories >= 0) {
         outStr = todo->categoriesStr();
         outStr.replace(QLatin1Char(','), QLatin1Char('\n'));
@@ -1800,7 +1778,7 @@ void CalPrintPluginBase::drawTodo(int &count,
     for (const KCalendarCore::Todo::Ptr &todo : std::as_const(t)) {
         tl.append(todo);
     }
-    KCalendarCore::Todo::List sl = mCalendar->sortTodos(tl, sortField, sortDir);
+    KCalendarCore::Todo::List sl = mCalendar->sortTodos(std::move(tl), sortField, sortDir);
 #endif
 
     int subcount = 0;
